### Effects of different parameters in the CIR model
## Define the SDE model
(drift <- c("-(x1-1)", "-(x2-5)", "-5*(x3-1)", "-(x4-1)")) 
(diffusion <- matrix(c("sqrt(max(x1, 0))", 
                       "sqrt(max(x2, 0))", 
                       "sqrt(max(x3, 0))", 
                       "(1/5)*sqrt(max(x4, 0))"), 4, 1)) # diffusion coefficient (2x3 matrix)
mod <- setModel(drift = drift, diffusion = diffusion, 
                state.variable = c("x1", "x2", "x3", "x4"))
## Define the sampling times
samp <- setSampling(Terminal = 10, n = 5000)
## Define the statistical model
smod <- setYuima(model = mod, sampling = samp)
## simulation and plot
## note that there is no unknown parameter in this case
set.seed(117) # fix a seed
res <- simulate(smod, xinit = rep(1,4)) # simulation
plot(res, plot.type = "single", 
     col = c("black","red","blue","green"),
     ylab = "Xt", main = "CIR models with different parameters") 
