### Simulation of the Heston model
## Define the SDE model
(drift <- c("mu*S", "-theta*(V-v)")) # drift coefficient
(diffusion <- matrix(c("sqrt(max(V,0))*S", "gamma*sqrt(max(V,0))*rho",
                      0, "gamma*sqrt(max(V,0))*sqrt(1-rho^2)"),
                     2,2)) # diffusion coefficient
mod <- setModel(drift = drift, diffusion = diffusion,
                state.variable = c("S", "V")) 
### characters for state variables are arbitrary
## Define the sampling times
samp <- setSampling(n = 1000)
## Define the statistical model
heston <- setYuima(model = mod, sampling = samp)
## simulation and plot
set.seed(100)
x0 <- c(1, 0.1) # initial value
param <- list(mu = 0.03, theta = 3, v = 0.09, 
              gamma = 0.3, rho = -0.6) # true parameters
result <- simulate(heston, xinit = x0, 
                   true.parameter = param) # simulation
plot(result, col = c("red", "blue"), lwd = 2) # plot