## Random initial condition: CIR model
## Define the SDE model
mod <- setModel(drift = "-theta*(x-mu)",
                diffusion = "sigma * sqrt(max(x, 0))",
                xinit = "rgamma(1, 2*theta*mu/sigma^2, 2*theta/sigma^2)")
## Define the sampling times
n <- 500
samp <- setSampling(Terminal = 0.1, n = n) # Initial = 0
## Define the statistical model
cir <- setYuima(model = mod, sampling = samp)
## simulation and plot
set.seed(123) # fix a seed
theta <- 3
mu <- 0.09
sigma <- 0.3
param <- list(theta = theta, mu = mu, sigma = sigma) # the true parameter values
# Simulation
res <- simulate(cir, true.parameter = param)
plot(res) # plot

simulateXT <- function(smod, param){
  out <- simulate(smod, true.parameter = param)
  XT <- tail(get.zoo.data(out)[[1]], n = 1) # Extract the terminal value
  return(XT)
}
MC <- 5000
res.mc <- replicate(MC, simulateXT(cir, param))
hist(res.mc, freq = FALSE, breaks = 25, col = "lightblue", border = "white")
curve(dgamma(x, shape = 2*theta*mu/sigma^2, rate = 2*theta/sigma^2),
      add = TRUE, col = "red")
