### Simulation of a SDE by the yuima package
library(yuima) # Load the yuima package
## Define the SDE model
mod <- setModel(drift = "-theta*x", # drift coefficient
                diffusion = "1/(1+x^2)", # diffusion coefficient
                state.variable = "x" # state variable (can be omitted because the default value is "x")
)
str(mod) # structure of mod
## Define the sampling times
n <- 1000
samp <- setSampling(Initial = 0, # initial time (can be omitted because the default value is 0)
                    Terminal = 1, # terminal time (can be omitted because the default value is 1)
                    n = n # number of divisions
)
str(samp) # structure of samp
## Define the statistical model
smod <- setYuima(model = mod, # SDE model
                 sampling = samp # sampling times
)
str(smod) # structure of smod
## simulation and plot
set.seed(123) # fix a seed
x0 <- 0 # the initial value of Xt
param <- list(theta = 3) # the true parameter value
# Simulation
res <- simulate(smod, # the statistical model
                xinit = x0, # initial value
                true.parameter = param # parameter value
)
plot(res) # plot