### Simulation of a multi-dimensional SDE
## Define the SDE model
(drift <- c("-3*x1", "-x1 - 2*x2")) # drift coefficient (2-dim. vector)
(diffusion <- matrix(c(1, "x1", 0, 3, "x2", 0), 2, 3)) # diffusion coefficient (2x3 matrix)
mod <- setModel(drift = drift, diffusion = diffusion, 
                state.variable = c("x1", "x2") 
                # state variable (can NOT be omitted!)
                )
str(mod) # structure of mod
# The remainder is analogous to the one-dim. case!
## Define the sampling times
n <- 1000
samp <- setSampling(n = n)
## Define the statistical model
smod <- setYuima(model = mod, sampling = samp)
## simulation and plot
## note that there is no unknown parameter in this case
set.seed(123) # fix a seed
res <- simulate(smod) # simulation (default init. vals are 0)
plot(res) # plot
plot(res, plot.type = "single", col = c("red", "blue"),
     ylab = "Xt") # plot in a single window
